Package: iterativeBMA
Type: Package
Title: The Iterative Bayesian Model Averaging (BMA) algorithm
Version: 1.71.0
Date: 2009-7-22
Author: Ka Yee Yeung, University of Washington, Seattle, WA, with
        contributions from Adrian Raftery and Ian Painter
Maintainer: Ka Yee Yeung <kayee@u.washington.edu>
Description: The iterative Bayesian Model Averaging (BMA) algorithm is
        a variable selection and classification algorithm with an
        application of classifying 2-class microarray samples, as
        described in Yeung, Bumgarner and Raftery (Bioinformatics 2005,
        21: 2394-2402).
Depends: BMA, leaps, Biobase (>= 2.5.5)
License: GPL (>= 2)
URL: http://faculty.washington.edu/kayee/research.html
biocViews: Microarray, Classification
git_url: https://git.bioconductor.org/packages/iterativeBMA
git_branch: devel
git_last_commit: c138cda
git_last_commit_date: 2026-04-28
Repository: Bioconductor 3.24
Date/Publication: 2026-05-18
NeedsCompilation: no
Packaged: 2026-05-18 22:28:57 UTC; biocbuild
Built: R 4.6.0; ; 2026-05-19 04:56:20 UTC; unix
